@@ -22,8 +22,7 @@ class SocketClient:
 
         self.host = host
         self.port = port
-        self.logger = logger(self.__class__.__name__)
-        self.logger.disabled = not logger_enabled
+        self.logger = logger(self.__class__.__name__, enabled=logger_enabled)
         self.connection_timeout = connection_timeout
 
         if initialize:
